@@ -1,22 +1,14 @@
-/*************************************************************************
- *  Copyright (C) 2010,2011 by Volker Lanz <vl@fidra.de>                 *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010-2011 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2018 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
 
-#if !defined(KPMCORE_COREBACKENDPARTITIONTABLE_H)
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
+#ifndef KPMCORE_COREBACKENDPARTITIONTABLE_H
 #define KPMCORE_COREBACKENDPARTITIONTABLE_H
 
 #include "core/partitiontable.h"
@@ -103,6 +95,47 @@ public:
       */
     virtual bool updateGeometry(Report& report, const Partition& partition, qint64 sector_start, qint64 sector_end) = 0;
 
+    /**
+     * Get the UUID of a partition in the partition table (GPT only).
+     * The partition UUID is known as PARTUUID by several utilities. The device-manager links
+     * the device under /dev/disk/by-partuuid/<uuid>.
+     * @param report the report to write information to
+     * @param partition the partition to get the UUID for
+     * @return the partition UUID
+     */
+    virtual QString getPartitionUUID(Report& report, const Partition& partition) = 0;
+
+    /**
+     * Set the label of a partition in the partition table (GPT only).
+     * The label is set in the GPT partition name entry. The partition name is known as PARTLABEL by
+     * several utilities. The device-manager links the device under /dev/disk/by-partlabel/<label>.
+     * @param report the report to write information to
+     * @param partition the partition to set the label for
+     * @param label the new label for the partition
+     * @return true on success
+     */
+    virtual bool setPartitionLabel(Report& report, const Partition& partition, const QString& label) = 0;
+
+    /**
+     * Set the UUID of a partition in the partition table (GPT only).
+     * The partition UUID is known as PARTUUID by several utilities. The device-manager links
+     * the device under /dev/disk/by-partuuid/<uuid>.
+     * @param report the report to write information to
+     * @param partition the partition to set the UUID for
+     * @param uuid the new UUID for the partition
+     * @return true on success
+     */
+    virtual bool setPartitionUUID(Report& report, const Partition& partition, const QString& uuid) = 0;
+
+    /**
+     * Set the attributes of a partition in the partition table (GPT only).
+     * @param report the report to write information to
+     * @param partition the partition to set the attributes for
+     * @param attrs the new attributes for the partition
+     * @return true on success
+     */
+    virtual bool setPartitionAttributes(Report& report, const Partition& partition, quint64 attrs) = 0;
+
     /**
      * Set the system type (e.g. 83 for Linux) of a partition. The type to set is taken from
      * the partition's file system.
