@@ -55,12 +55,12 @@ std::unique_ptr<CoreBackendPartitionTable> SfdiskDevice::openPartitionTable()
 bool SfdiskDevice::createPartitionTable(Report& report, const PartitionTable& ptable)
 {
     QByteArray tableType;
-    if (ptable.type() == PartitionTable::msdos || ptable.type() == PartitionTable::msdos_sectorbased)
+    if (ptable.type() == PartitionTable::msdos)
         tableType = QByteArrayLiteral("dos");
     else
         tableType = ptable.typeName().toLocal8Bit();
 
-    ExternalCommand createCommand(report, QStringLiteral("sfdisk"), { m_device->deviceNode() } );
+    ExternalCommand createCommand(report, QStringLiteral("sfdisk"), { QStringLiteral("--wipe=always"), m_device->deviceNode() } );
     if ( createCommand.write(QByteArrayLiteral("label: ") + tableType +
                                     QByteArrayLiteral("\nwrite\n")) && createCommand.start(-1) ) {
         return createCommand.output().contains(QStringLiteral("Script header accepted."));
