@@ -28,6 +28,8 @@ QStringLiteral("mdadm"),
 QStringLiteral("mount"),
 QStringLiteral("umount"),
 QStringLiteral("smartctl"),
+QStringLiteral("fstyp"),
+QStringLiteral("gpart"),
 
 // FileSystem utilties
 QStringLiteral("bcachefs"),
@@ -64,6 +66,7 @@ QStringLiteral("jfs_tune"),
 QStringLiteral("fsck.jfs"),
 QStringLiteral("mkfs.jfs"),
 QStringLiteral("mkswap"),
+QStringLiteral("swapctl"),
 QStringLiteral("swaplabel"),
 QStringLiteral("swapon"),
 QStringLiteral("swapoff"),
